pub fn lower<'a, E>(expression: E) -> Function<'a>where
E: Into<Expression<'a>>,Expand description
Converts the result of the expression into lowercase string.
pub fn lower<'a, E>(expression: E) -> Function<'a>where
E: Into<Expression<'a>>,Converts the result of the expression into lowercase string.